#!/bin/bash 
# projectid: 51838
# name: PATCH-LW2X06-DRIVER-1.0.8.sh
# date: 2024/1/12

ret_success=0
ret_success_restart=1
ret_success_reboot=2
ret_fail_roolback=6
ret_fail_others=7
script_name=$(basename $0)
work_dir=$(dirname $0)
at_tool=${work_dir}/packages/at.2506
upgrade_script=${work_dir}/packages/upgrade.sh

log_exit() 
{
    echo `date` "$script_name upgrade: ${1} exit $2" 
    exit ${2}
}

# Check pid vid、module model and version
check_version()
{
    # 1. check pid vid of FM650-CN
    vpid=$(lsusb |grep "2cb7:0a05")
    if [ -z "$vpid" ]; then
        log_exit "invalid pid vid" $ret_fail_others
    fi

    $at_tool -d /dev/ttyUSB1 ATE0
    sleep 1
    #send "AT" to flush serial
    $at_tool -d /dev/ttyUSB1 AT
    sleep 1
    reply=$($at_tool -d /dev/ttyUSB1 ATI)
    sleep 1
    echo "ATI:$reply"

    # 2. check module model
    moduleModel=$(echo "$reply" | grep "FM650-CN")
    if [ -z "$moduleModel" ]; then
        log_exit "invalid module name" $ret_fail_others
    fi

    # 3. check version, if current version is not equal new version, continue, if equal, exit 
    newVersion="86600.1000.00.05.17.14"
    curVersion=$(echo "$reply" |grep -oE "Revision:\s+\S+" |awk '{print $2}')
    echo "newVersion:$newVersion  curVersion:$curVersion"
    if [ "$curVersion" = "$newVersion" ]; then
        log_exit "already new version, upgrade success" $ret_success
    fi
}

# Determine if there is 400M of space in the root directory.
# If greater than, continue; if less than, exit
check_disk_space()
{
    AvailableSpace=$(df | grep -w "\/" | awk '{print $4}')
    AvailableSpace=$(expr $AvailableSpace / 1024)
    if [ $AvailableSpace -lt 400 ]; then
        echo "Available space is less than 400M, upgrade is not recommended !"
        exit $ret_fail_others
    fi
    echo "Available space is more than 400M, upgrade continue"
}

install()
{
    echo "upgrade start."

    check_version
    check_disk_space

    # Backend upgrade, patch is finished
    nohup $upgrade_script >> /var/log/update.log 2>&1 &

    log_exit "patch finish and return success, module will backend upgrade." $ret_success
}

uninstall()
{
    log_exit "Not supported roolback, please upgrade other patch" $ret_success
}

if [ "$1" == "install" ];then
    install
elif [ "$1" == "uninstall" ]; then
    uninstall
else
    log_exit "invalid args" $ret_fail_others
fi
