#!/bin/bash

ret_success=0
ret_success_restart=1
ret_success_reboot=2
ret_fail_roolback=6
ret_fail_others=7
script_name=$(basename $0)
work_dir=$(dirname $0)
at_tool=${work_dir}/at.2506

log_exit() 
{
    echo `date` "$script_name upgrade: ${1} exit $2" 
    exit ${2}
}

# upgrade
upgrade_module()
{
    #send "AT" to flush serial
    upgradeTool=${work_dir}/upgrade_tool_v1.1.4.0
    upgradePac=${work_dir}/86600.1000.00.05.17.14.pac

    $upgradeTool -f $upgradePac
    ret=$?
    if [ $ret -eq 0 ]; then
        echo "module upgrade success, continue"
    else
        log_exit "module upgrade failure ret:$ret, exit" $ret_fail_others
    fi
}

# set low-power level
set_low_power_level()
{
    for ((waitTimes = 0; waitTimes < 60; waitTimes += 5)); do
        # Check if /dev/ttyUSB1 files exist
        if [ -e /dev/ttyUSB1 ]; then
            echo "/dev/ttyUSB1 exist, continue"

            sleep 15    #Waiting for stability

            $at_tool -d /dev/ttyUSB1 ATE0
            sleep 1
            $at_tool -d /dev/ttyUSB1 AT
            sleep 1
            reply=$($at_tool -d /dev/ttyUSB1 ATI)
            sleep 1
            newVersion="86600.1000.00.05.17.14"
            curVersion=$(echo "$reply" |grep -oE "Revision:\s+\S+" |awk '{print $2}')
            if [ "$curVersion" = "$newVersion" ]; then
                echo "upgrade success, continue to set low-power level"
            else
                log_exit "upgrade failure, please check module model" $ret_fail_others
            fi

            $at_tool -d /dev/ttyUSB1 AT+GTSET=\"SIMPHASE\",0,0
            sleep 1

            $at_tool -d /dev/ttyUSB1 AT+CFUN=1,1
            return 0
        else
            sleep 5  # Sleep for 5 seconds
            echo "/dev/ttyUSB1 don't exist, wait $((waitTimes + 5))s in 60s, continue"
        fi
    done

    log_exit "wait timeout, exit" $ret_fail_others
}

echo "module backend upgrade start."
# wait patch report orch reply
sleep 10

upgrade_module
set_low_power_level

log_exit "module backend upgrade finish." $ret_success
